summaryrefslogtreecommitdiffstats
path: root/libkmid/player.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /libkmid/player.h
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkmid/player.h')
-rw-r--r--libkmid/player.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/libkmid/player.h b/libkmid/player.h
index cb21a9674..6a9210292 100644
--- a/libkmid/player.h
+++ b/libkmid/player.h
@@ -379,11 +379,11 @@ class KMID_EXPORT MidiPlayer
* @param gotomsec the number of milliseconds to go to . A subsequent call to
* play() will start playing the song from that moment, instead of the
* beginning.
* @param midistat a MiditqStatus object that will contain the status in
* which the MIDI device would be if it would have arrived to this situation by
* a normal playing of the song.
*/
- void setPos(ulong gotomsec, class MiditqStatus *midistat);
+ void setPos(ulong gotomsec, class MidiStatus *midistat);
/**
* Changes the speed at which a song is played. The song's tempo is multiplied
@@ -379,11 +379,11 @@ class KMID_EXPORT MidiPlayer
* play() will start playing the song from that moment, instead of the
* beginning.
- * @param midistat a MiditqStatus object that will contain the status in
+ * @param midistat a MidiStatus object that will contain the status in
* which the MIDI device would be if it would have arrived to this situation by
* a normal playing of the song.